/* packet-hi2.c
 * Routines for Wireless Certificate Extension (RFC3770)
 *  Ronnie Sahlberg 2005
 *
 * $Id: packet-hi2-template.c 27390 2009-02-07 14:33:47Z wmeier $
 *
 * Wireshark - Network traffic analyzer
 * By Gerald Combs <gerald@wireshark.org>
 * Copyright 1998 Gerald Combs
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
# include "config.h"
#endif

#include <glib.h>
#include <epan/packet.h>
#include <epan/oids.h>
#include <epan/conversation.h>
#include <epan/asn1.h>

#include <stdio.h>
#include <string.h>

#include "packet-ber.h"
#include "packet-hi2.h"
#include "packet-wlancertextn.h"
#include "packet-x509af.h"
#include "packet-x509ce.h"
#include "packet-x509sat.h"

#define PNAME  "ES 201.671 v3.1.1 hi2"
#define PSNAME "HI2OPERATIONS"
#define PFNAME "hi2"

/* Initialize the protocol and registered fields */
int proto_hi2 = -1;
#include "packet-hi2-hf.c"

/* Initialize the subtree pointers */
#include "packet-hi2-ett.c"

#include "packet-hi2-fn.c"


/*--- proto_register_hi2 ----------------------------------------------*/
void proto_register_hi2(void) {

  /* List of fields */
  static hf_register_info hf[] = {
#include "packet-hi2-hfarr.c"
  };

  /* List of subtrees */
  static gint *ett[] = {
#include "packet-hi2-ettarr.c"
  };

  /* Register protocol */
  proto_hi2 = proto_register_protocol(PNAME, PSNAME, PFNAME);

  /* Register fields and subtrees */
  proto_register_field_array(proto_hi2, hf, array_length(hf));
  proto_register_subtree_array(ett, array_length(ett));

}


/*--- proto_reg_handoff_hi2 -------------------------------------------*/
void proto_reg_handoff_hi2(void) {
#include "packet-hi2-dis-tab.c"
  oid_add_from_string("HI2Operations","0.4.0.2.2.1.10");
}

/*
void
proto_reg_handoff_hi2(void)
{
    static gboolean inited = FALSE;
    
    if( !inited ) {
        
    hi2_handle = create_dissector_handle(dissect_hi2, proto_hi2);
    dissector_add("udp.port", global_hi2_port, hi2_handle);
    inited = TRUE;
    }
}
*/
                                                                                         